summaryrefslogtreecommitdiffstats
path: root/app
diff options
context:
space:
mode:
Diffstat (limited to 'app')
-rw-r--r--app/theme_provider.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/app/theme_provider.h b/app/theme_provider.h
index cd97fa8..1db73e1 100644
--- a/app/theme_provider.h
+++ b/app/theme_provider.h
@@ -71,20 +71,23 @@ class ThemeProvider {
// Gets the NSImage with the specified |id|.
//
// The bitmap is not assumed to exist. If a theme does not provide an image,
+ // if |allow_default| is true, then the default image will be returned, else
// this function will return nil.
- virtual NSImage* GetNSImageNamed(int id) const = 0;
+ virtual NSImage* GetNSImageNamed(int id, bool allow_default) const = 0;
// Gets the NSColor with the specified |id|.
//
- // The color is not assumed to exist. If a theme does not provide an color,
- // this function will return nil.
- virtual NSColor* GetNSColor(int id) const = 0;
+ // The color is not assumed to exist. If a theme does not provide an color, if
+ // |allow_default| is true, then the default color will be returned, else this
+ // function will return nil.
+ virtual NSColor* GetNSColor(int id, bool allow_default) const = 0;
// Gets the NSColor for tinting with the specified |id|.
//
// The tint is not assumed to exist. If a theme does not provide a tint with
- // that id, this function will return nil.
- virtual NSColor* GetNSColorTint(int id) const = 0;
+ // that id, if |allow_default| is true, then the default tint will be
+ // returned, else this function will return nil.
+ virtual NSColor* GetNSColorTint(int id, bool allow_default) const = 0;
#elif defined(OS_POSIX) && !defined(TOOLKIT_VIEWS)
// Gets the GdkPixbuf with the specified |id|. Returns a pointer to a shared
// instance of the GdkPixbuf. This shared GdkPixbuf is owned by the theme